**********************************************************************************************************************************
**
**FOIA Project--FOIA Baseline and Sensitive Main Analysis
**David Lewis and Abby Wood
**January 19, 2017
**Data: finalfoiadataforanalysis070918.csv
**Description: This is the batch file for the July 2016 R&R for JPART
**********************************************************************************************************************************



**********************************************************************************************************************************
***DATA PREPARATION****
**********************************************************************************************************************************
**The following commands will take the data from the .csv file and prepare them for the analysis in the article.

********Taking care of some miscoding: CEQ was mistakenly coded as being a bureau. Army was not coded as part of a cabinet agency.
** PBGC was not listed as part of labor (a cabinet department) and STB was not listed as part of DOT (a cabinet department)

replace bureau=0 if agencyid==17
replace cabinet=1 if agencyid==1
replace cabinet =1 if agencyid==5
replace cabinet=1 if agencyid==110
replace bureau=1 if agencyid==110 
replace bureau=1 if agencyid== 119
replace cabinet=1 if agencyid==119

**Changing the format of variables from strings to numbers and handling some missing values, changing NA to missing. 

destring employmentmar, replace force
destring numberofreq, replace force
destring budgetoutlays2010, replace force
destring stafffy2010, replace force
destring texemption, replace force
destring bad, replace force
destring fydateonlyprob, replace force
destring fee, replace force
destring issarequest, replace force
destring idaysrespond, replace force
destring isresp, replace force
destring norecords, replace force
destring prest, replace force
destring dmest, replace force
destring totalpart, replace force

**********************************************************************************************************************************
*********Create some additional variables*****************************************************************************************
**********************************************************************************************************************************

**This generates the request type (baseline or sensitive). requesttype1 will be baseline and requesttype2 will be sensitive.
tab request, generate(requesttype)

**This logs the number of FOIA requests in FY2010. This variables is very left skewed. The median is 244 requests but the mean
**is 6790. The min is 0 and the max is 130,098.
generate lnreq=ln(numberofreq)

**This logs our two measures of size (agency employment & budget outlays). Both agency employment and budgets in 2010 were 
**quite skewed. Employment varies from 10 to 645,950 with a median of 1713 and mean of 26804. Similarly, budget varies from 
**$3,000,000 to $854,000,000,000. The median is $480,000,000 and the mean is 38,100,000,000.
generate lnemp=ln(employmentmar)
generate lnbudg=ln(1+budgetoutlays2010)

**This logs number appointees. Again, another skewed variable. Agencies have significantly different numbers of appointees.
**Please also note that DOJ and STATE have high numbers of appointees because of ambassadors and U.S. Attorneys/U.S. Marshals.
**The # of appointees varies from 0 to 356 and the median number is 6 and the mean is 27.
generate lnapp=ln(1 + totalapp)

**FOIA workload. The command creates a variable that that measures agency workload adjusted for the number of employees
**working on FOIA. Agencies can always make errors because they are overworked.
generate workload = numberofreq/stafffy2010

**The Selin insulation measures are basically -1 * our concept of a politicized agency, 
**so to get everything pointing in the same direction (more positive = more politicized), 
**we multiply her measures by -1
generate dmpolit = -1 * dmest
generate prpolit = -1 * prest

**FOIA Process Details
**This creates indicator for whether agency has benefits programs that generates FOIA requests
generate benefit=0 if benefits !=.
replace benefit=1 if benefits>0

***************************************************************************************************************************************************
**Dependent Variables
***************************************************************************************************************************************************

**This final version of bad excludes fiscal year cases but includes fees.
generate bad3=bad
replace bad3=1 if fee==1&fy==0

***************************************************************************************************************************************************
**Independent Variables: Politicization
***************************************************************************************************************************************************

********************Agency Structure as a Proxy for Politicization*********************************************************************************
**Location
**This creates and indicator for Independent Regulatory Commission
generate IRC=0
replace IRC=1 if agencyid==13|agencyid==15|agencyid==47|agencyid==52|agencyid==54|agencyid==66|agencyid==87|agencyid==95|agencyid==114

**This creates an indicator for independent agencies (including IRCs and other independent agencies)
generate independenta=0
replace independenta=1 if department=="Independent"

**If we want to separate out independent commissions from independent agencies that are not commissions, this command does that.
generate indadmin=0
replace indadmin=1 if independenta==1&commission==0

** If we want to combine eop and cabinet
generate eopcab=0
replace eopcab=1 if eop==1 | cabinet==1

** Interactions. The interactions allow the effect of agency insulation to vary based upon request type (i.e., not political vs. political)
** and also the effect of agency structure to only matter for political requests. 
generate reqeop = requesttype2*eop
generate reqcab = requesttype2*cabinet
generate reqeopcab = requesttype2*eopcab
generate reqind = requesttype2*indadmin

**This creates the interaction of the (negative) selin measures and request type(sensitive)
generate reqdm = requesttype2*dmpolit
generate reqpr = requesttype2*prpolit

*********************Location of the FOIA Office in the Office of the Secretary as a Proxy for Politicization**************************************

**Description: Now to create indicators for the location of the FOIA office. This comes from the FOIA Contact Information in the dataset
**Note that we take out cases where the secretariat is not political (i.e., is run by a careerist). This excludes
**agencies such as Tricare which is a DOD bureau run by a careerist but also interagency commissions
**where members of the commission do not work full time for the agency. This includes agencies such as the Federal Financial
**Institutions Examination Council which is an interagency body chaired by the Comptroller of the Currency (an appointee in the Treasury Department).
**The agencies affected are the Defense Technology Information Service, Tricare, National Capital Planning Commission, FFIEC, and the
**Committee for Purchase from People who are Blind or Severely Disabled.

generate secretariat=0 if fclocation != "Unknown"
replace secretariat=1 if fclocation=="Executive Secretariat" | fclocation=="Privacy Office/Executive Secretariat" | fclocation=="Office of the Secretary" |  fclocation=="Office fo the Secretary" | fclocation=="Office of the Secretarty" | fclocation=="Office of Clerk of the Board" | fclocation=="Consumer Affairs, Secretariat" |  fclocation=="Secretariat"| fclocation=="Office of the Director"
replace secretariat=0 if agencyid==28|agencyid==122|agencyid==79|agencyid==57|agencyid==12

**Now an interaction with politically sensitive request
generate reqsec = requesttype2*secretariat

**Interactions between secretariat and location
generate eosec=eop*secretariat
generate cabsec=secretariat*cabinet
generate indasec=indadmin*secretariat
generate ircsec=IRC*secretariat
generate secrec=secretariat*requesttype2

************************************Percentage of Appointees in the Agency as a Measure of Politicization******************************************

**Percentage of agency employees that are appointees. We use the first as the most natural measure and its logged version since it is skewed.
generate politicization =( totalapp/employmentmar)*100
generate lnpolit = ln(.01+politicization)

**This creates the interaction of the appointee percentage and request type(sensitive)
generate reqpol = requesttype2*politicization

**Now an interaction between politicization and secretariat
generate politsec = politicization*secretariat

**Finally, the sfgs_pol1 measure on amount of appointee influence vs. careerist influence
**From survey 2007-2008  
** Possible range is -4 to 4, with 0 indicating equal influence, 
** -4 max careerist influence, 4 max appointee influence.
generate reqpol_sfgs1=requesttype2*sfgs_pol1
generate reqpol_sfgs2=requesttype2*sfgs_pol2




***************************************************************************************************************************************************
**********ANALYSIS IN THE PUBLISHED PAPER**********************************************************************************************************
***************************************************************************************************************************************************


***************************************************************************************************************************************************
**********Summary data on confirmation and repsonse ***********************************************************************************************
***************************************************************************************************************************************************
**Data and Analytic Strategy (pp.4-6)
tab confirm
summarize timeconfirm
summarize timeconfirm if requesttype1==1
summarize timeconfirm if requesttype2==1

tab respond
summarize timerespond
summarize timerespond if requesttype1==1
summarize timerespond if requesttype2==1

list agencyname if respond==0

summarize idaysrespond
summarize isrespond

***************************************************************************************************************************************************
**********Analysis for Appendix Tables 1 and 2 (p. 5, FN 6) ********************************************************************
***************************************************************************************************************************************************

sort agencyid
list agencyid agencyname if respond==0

sort agencyid
list agencyid agencyname timerespond request if bad==1&timerespond>30
list agencyid agencyname timerespond request if fee==1&timerespond>30

***************************************************************************************************************************************************
**Summary data on agency location 
***************************************************************************************************************************************************
** p. 7, "Other Variables"
ttest timeconfirm, by(eop)
ttest timerespond, by(eop)
ttest idaysrespond, by(eop)

ttest timeconfirm, by(cabinet)
ttest timerespond, by(cabinet)
ttest idaysrespond, by(cabinet)

ttest numberofreq, by(eopcab)
ttest stafffy2010, by(eopcab)
ttest workload, by(eopcab)

ttest secretariat, by(eop)
ttest secretariat, by(cabinet)
ttest secretariat, by(eopcab)

ttest timeconfirm, by(secretariat)
ttest timerespond, by(secretariat)
ttest idaysrespond, by(secretariat)

ttest numberofreq, by(secretariat)
ttest stafffy2010, by(secretariat)
ttest workload, by(secretariat)


***************************************************************************************************************************************************
** TABLE 1. Summary Statistics (p. 8)**
***************************************************************************************************************************************************
** NOTE: These summary stats for structure are different in two cases from Table 1 in the text--cabinet, IRC. This happened because the summary stats
** were calculated before the changes above were made. The affect variables include cabinet, independent agency, and bureau. Specifically, the
** mean for cabinet is 0.42 rather than 0.39. The mean for indadmin is 0.25 rather than 0.24. The mean for bureau is 0.29 rather than 0.27.

summarize confirm respond timeconfirm timerespond idaysrespond tex bad3 secretariat eop cabinet indadmin com bureau employment totalapp benefit numberofreq requesttype2


***************************************************************************************************************************************************
** Table 2. TIME TO CONFIRM
***************************************************************************************************************************************************

** We estimate generalized gamma models here since none of the variables are time-varying and there is good reason to think that the hazard
** rate is increasing at the start and then decreasing. It is also the best fit by the Akaike Information Criteria (AIC) and I could reject the null
** of the Weibull and Exponential which are nested.

** First some tests based upon AIC. Gamma model seems best both by estimates of kappa and sigma and AIC.
stset timeconfirm, failure(confirm)
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(exponential)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(weibull)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(loglog)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(lognormal)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(gompertz)
estat ic

** MAIN specifications that appear in Table 2.
stset timeconfirm, failure(confirm)
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

** Robustness check with a control for the agencies that Issa's request covered. This model was referenced in fn 7 on p. 5 in the text.
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2 issaagency, cluster(agencyid) distribution(ggamma)

** LR Tests. So, LR test indicates that we cannot reject the null that including the interaction terms does not improve the fit of the models.

streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, distribution(ggamma)
est store A
streg secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, distribution(ggamma) 
lrtest A

streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, d(gamma)
est store B
streg secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2,  d(gamma)
lrtest B

** Here is where we generate predicted values and then summarize them for high, low percentages of appointees, etc.
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
predict tc_hat, median time

summarize tc_hat if eop==0 & cabinet==0 & indadmin==0, detail
summarize tc_hat if eop==1, detail

summarize tc_hat if cabinet==0
summarize tc_hat if cabinet==1

** The estimated effects are tricky here because agencies with FOIA offices in the secretariat have appointee percentages of 1.49 vs. 2.97 for those outside.

summarize tc_hat if secretariat==0, detail
summarize tc_hat if secretariat==1, detail
summarize tc_hat if secrec==1, detail


***************************************************************************************************************************************************
** TABLE 3. TIME TO RESPOND** (ISSA ANALYSIS FOR THIS TABLE IS SEPARATE AND INCLUDED BELOW) *******************************************************
***************************************************************************************************************************************************
** Now to make sure we have the right functional form. Gamma model seems best both by estimates of kappa and sigma and AIC.
stset timerespond, failure(respond)
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(exponential)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(weibull)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(loglog)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(lognormal)
estat ic
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) dist(gompertz)
estat ic

** Main specifications in Table 3. 
stset timerespond, failure(respond)
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

** LR Tests. So, LR test indicates that we cannot reject the null that including the interaction terms does not improve the fit of the models.

streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, distribution(ggamma)
est store C
streg secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, distribution(ggamma) 
lrtest C

streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, d(gamma)
est store D
streg secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2,  d(gamma)
lrtest D

** Robustness check with a control for the agencies that Issa's request covered. This model was referenced in fn 7 on p. 5 in the text.
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2 issaagency, cluster(agencyid) distribution(ggamma)
streg secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2 issaagency, cluster(agencyid) distribution(ggamma)
streg secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2 issaagency, cluster(agencyid) distribution(ggamma)

** Now secretariat.
stcurve, survival at1(secretariat=0) at2(secretariat=1)

** Here is where we generate predicted values and then summarize them
streg secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

predict tr_hat, median time

summarize tr_hat if eop==0 & cabinet==0 & indadmin==0, detail
summarize tr_hat if eop==1, detail

summarize tr_hat if cabinet==0
summarize tr_hat if cabinet==1

centile lnreq, centile(25, 75)
summarize tr_hat if lnreq > 3.9 & lnreq < 4
summarize tr_hat if lnreq > 8 & lnreq < 8.1

summarize tr_hat if secretariat==0, detail
summarize tr_hat if secretariat==1, detail

summarize tr_hat if requesttype2==0, detail
summarize tr_hat if requesttype2==1, detail


***************************************************************************************************************************************************
********** Table 4. Models of Response Quality. These do not show too much and the exemptions models are sensitive to specification. **************
***************************************************************************************************************************************************
** We model this without the requesttype since only one sensitive request claimed exemptions and did not have a norecords response. Two sensitive
** requests were both norecords responses and exemptions responses since they sent a FOIA docket with exemptions.
poisson tex secretariat eop cabinet indadmin bureau lnemp lnreq benefit if respond==1&norecords==0&requesttype2==0, cluster(agencyid)

** In the models of poor response EOP agencies are dropped because none produced a bad response. In these models, poor response includes fees 
** charged but excludes cases where fiscal year was sent rather than calendar year. Including or exclude fiscal year cases as bad responses does 
** not make much difference but we cannot definitively rule out that the senders of the FOIA requests might have told agencies that fiscal year 
** was OK.

** The sample on which these models are estimated is systematically different from the overall sample. There are fewer politically sensitive 
** requests, and these agencies are more likely to be cabinet agencies. Politicization is a full point lower for those in the respond group. 

logit bad3 secretariat cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2 if respond==1&eop==0, cluster(agencyid)
mfx

** We do not include the interactions in the table because they do not improve the fit but here they are.
logit bad3  secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid)

** Robustness Check. These models control for Issa contact about their FOIA process. This model was referenced in fn 7 on p. 5 in the text.
logit bad3 secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2 issaagency, cluster(department)
poisson tex secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2 issaagency if respond==1&norecords==0, cluster(agencyid)


***************************************************************************************************************************************************
****************************** TABLE 3: ISSA Analysis *********************************************************************************************
***************************************************************************************************************************************************

** We estimate a gamma model here because it is most flexible. We can reject the possibility of it being weibull, exponential, or log normal
** based upon the estimate of kappa which is about -1.80.
stset idays if issarequest == 1, failure(isresp)
streg  secretariat eop cabinet indadmin lnemp  lnreq benefit, cluster(department) distribution(ggamma)
estat ic
streg  secretariat eop cabinet indadmin lnemp  lnreq benefit, cluster(department) dist(weibull)
estat ic
streg  secretariat eop cabinet indadmin lnemp  lnreq benefit, cluster(department) dist(exponential)
estat ic
streg  secretariat eop cabinet indadmin lnemp  lnreq benefit, cluster(department) dist(gompertz)
estat ic
streg  secretariat eop cabinet indadmin lnemp  lnreq benefit, cluster(department) dist(loglog)
estat ic
streg  secretariat eop cabinet indadmin lnemp  lnreq benefit, cluster(department) dist(lognormal)
estat ic

** Models for Table 3 *****************************************************************************************************************************
stset idays if issarequest == 1, failure(isresp)
streg secretariat lnemp lnreq benefit, cluster(department) distribution(ggamma)
streg secretariat eop cabinet indadmin lnemp lnreq benefit, cluster(department) distribution(ggamma)

predict is_hat, median time

summarize is_hat if eop==0 & cabinet == 0 & indadmin == 0, detail
summarize is_hat if eop==1, detail

summarize is_hat if eop==0 & cabinet == 0 & indadmin == 0, detail
summarize is_hat if cabinet==1, detail

summarize is_hat if eop==0 & cabinet == 0 & indadmin == 0, detail
summarize is_hat if indadmin==1, detail

summarize is_hat if secretariat==0, detail
summarize is_hat if secretariat==1, detail

summarize is_hat if lnemp<5.38, detail
summarize is_hat if lnemp>9.64, detail


******************************************************************************************************************************************************
*** MECHANISM DISCUSSION:  Crowding Out (p. 12)
******************************************************************************************************************************************************

** Do politicized offices crowd out FOIA?  Calculate # FOIA e'ees / # e'ees, and multiply by 1/# requests
generate altman=stafffy2010/employmentmarch * 1/numberofreq
regress altman eop cabinet indadmin if employmentmarch > 50


** Do agencies with more programs respond poorly? These models have to be simple because PART limits the number of cases. We cannot reject the null
** that the number of programs evaluated via PART had no influenc on response times. This discussion is in FN 16 on p. 11.
stset timeconfirm, failure(confirm)
streg totalpart lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

stset timerespond, failure(respond)
streg totalpart lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

logit bad3 secretariat cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2 totalpart if respond==1&eop==0, cluster(agencyid)
poisson tex secretariat eop cabinet indadmin bureau lnemp lnreq benefit totalpart if respond==1&norecords==0&requesttype2==0, cluster(agencyid)



******************************************************************************************************************************************************
******************************************************************************************************************************************************
************************************** OTHER ROBUSTNESS CHECKS: MENTIONED IN FOOTNOTES OR MAIN TEXT **************************************************
******************************************************************************************************************************************************

******* APPOINTEE % POLITICIZATION: Models of Confirmation and Response using politicization (p.7) and APPENDIX E1 and E2 ****************************
stset timeconfirm, failure(confirm)
streg politicization eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg politicization reqpol eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

stset timerespond, failure(respond)
streg politicization eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg politicization reqpol eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)


******* SURVEY BASED MEASURE OF POLITICIZATION: Models of Confirmation and Response using SFGS measures of politicization (p.7). These are models in
** Appendix F1, F2. sfgs_pol1 is from 2007-2008 Survey on the Future of Government Service. It is the difference in appointee vs. careerist influence by agency.
** These models are somewhat simplified. There are fewer cases when we include only those agencies for which we have survey data. So, we include
** only the SFGS measures of politicization and exclude the structural variables. They are hard to get to estimate even in the simple specifcations.
** In the confirmation models we cannot reject the null that politicization has no influenc on confirmation. In the response models we can.

** Models of Confirmation with SFGS Measure of Politicization. This is the model in Appendix F.1.
stset timeconfirm, failure(confirm)
streg sfgs_pol1 lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

** Models of Response with SFGS Measure of Politicization. Thisis the model in Appendix F.2.
stset timerespond, failure(respond)
streg sfgs_pol1 lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

** Models of Response Quality. Appendix F.3.
logit bad3 sfgs_pol1 lnemp totalapp  benefit lnreq requesttype2, cluster(agencyid)
poisson tex sfgs_pol1 lnemp lnreq benefit if respond==1&norecords==0&requesttype2==0, cluster(agencyid)


******* SELIN MEASURE OF INSULATION: Models of Confirmation and Response (p.7) and APPENDIX E1 and E2. dmpolit is decision maker independence from Selin 2015 
*** multiplied by -1. prpolit is policy review independence from Selin 2015 multiplied by -1.

stset timeconfirm, failure(confirm)
streg dmpolit lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg dmpolit reqdm lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg politicization dmpolit lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

stset timerespond, failure(respond)
streg dmpolit lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)
streg dmpolit reqdm lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) distribution(ggamma)

** ISSA ANALYSIS FOR APPENDIX E2
stset idays if issarequest == 1, failure(isresp)
streg politicization eop cabinet indadmin bureau lnemp lnreq benefit, cluster(department) distribution(ggamma) 
streg dmpolit lnemp lnreq benefit, cluster(department) distribution(ggamma) 

******* MODELS WITH NATURAL LOG OF BUDGET: Models of Confirmation and Response (p.7). These are models in Appendix G1, G2. ***************************

stset timeconfirm, failure(confirm)
streg secretariat eop cabinet indadmin bureau totalapp lnreq benefit requesttype2 lnbudg, cluster(agencyid) distribution(ggamma)
streg secretariat secrec eop cabinet indadmin bureau totalapp lnreq benefit requesttype2 lnbudg, cluster(agencyid) distribution(ggamma)
streg secretariat eop reqeop cabinet reqcab indadmin reqind bureau totalapp lnreq benefit requesttype2 lnbudg, cluster(agencyid) distribution(ggamma)

stset timerespond, failure(respond)
streg secretariat eop cabinet indadmin bureau totalapp lnreq benefit requesttype2 lnbudg, cluster(agencyid) distribution(ggamma)
streg secretariat secrec eop cabinet indadmin bureau totalapp lnreq benefit requesttype2 lnbudg, cluster(agencyid) distribution(ggamma)
streg secretariat eop reqeop cabinet reqcab indadmin reqind bureau totalapp lnreq benefit requesttype2 lnbudg, cluster(agencyid) distribution(ggamma)

stset idays if issarequest == 1, failure(isresp)
streg secretariat eop cabinet indadmin lnreq benefit lnbudg, cluster(agencyid) distribution(ggamma)


******* COX MODELS: Models of Confirmation and Response (p.8). ****************************************************************************************
stset timeconfirm, failure(confirm)
stcox secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) nohr
stcox secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) nohr
stcox secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) nohr

stset timerespond, failure(respond)
stcox secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) nohr
stcox secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) nohr
stcox secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid) nohr

stset idays if issarequest == 1, failure(isresp)
stcox secretariat eop cabinet indadmin lnemp lnreq benefit, cluster(agencyid) nohr



******* LOGIT MODELS: Models of Confirmation and Response (p.8). These are Appendix H.1 and H2 *********************************************************
logit confirm secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid)
mfx
logit confirm secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid)
mfx

logit respond secretariat eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid)
mfx
logit respond secretariat secrec eop cabinet indadmin bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid)
mfx
logit respond secretariat eop reqeop cabinet reqcab indadmin reqind bureau lnemp totalapp lnreq benefit requesttype2, cluster(agencyid)
mfx

** Issa logit
logit isresp secretariat eop cabinet indadmin lnemp lnreq benefit if issaagency==1, cluster(agencyid)

